/*
 * @Company: hugeInfo
 * @Author: AI
 * @Date: 2025-04-17 16:30:00
 * @LastEditTime: 2025-04-23 16:41:01
 * @LastEditors: lwh
 * @Version: 1.0.0
 * @Description: 柱状图组件
 */
import React, { useEffect, useRef } from 'react';
import * as echarts from 'echarts/core';
import { BarChart } from 'echarts/charts';
import { GridComponent, TooltipComponent, LegendComponent } from 'echarts/components';
import { CanvasRenderer } from 'echarts/renderers';

echarts.use([BarChart, GridComponent, TooltipComponent, LegendComponent, CanvasRenderer]);

/**
 * data: array, // 数据
 * dataAxis: array, // x轴
 * barColor: array, // 柱状图颜色
 * isStacked: boolean, // 是否堆叠柱状图
 */
const MyChartBar = ({ data = [], dataAxis = [], barColor = ['#5fa6d4', '#1a6fb8'], isStacked = false }) => {
	const chartRef = useRef(null);
	const chartInstance = useRef(null);

	useEffect(() => {
		if (chartRef.current) {
			if (!chartInstance.current) {
				chartInstance.current = echarts.init(chartRef.current);
			}
			renderChart();
		}

		return () => {
			if (chartInstance.current) {
				chartInstance.current.dispose();
				chartInstance.current = null;
			}
		};
	}, [data, dataAxis, isStacked]);

	const renderChart = () => {
		if (!chartInstance.current) return;

		let series = [];
		let legendData = [];

		if (isStacked) {
			// 堆叠柱状图模式（化解成功和化解不成功）
			series = [
				{
					name: '化解成功',
					type: 'bar',
					stack: 'total',
					barWidth: '40%',
					itemStyle: {
						color: barColor[0]
					},
					emphasis: {
						focus: 'series'
					},
					data: data.map(item => item.resolveNum)
				},
				{
					name: '化解不成功',
					type: 'bar',
					stack: 'total',
					barWidth: '40%',
					itemStyle: {
						color: barColor[1]
					},
					emphasis: {
						focus: 'series'
					},
					data: data.map(item => item.unResolveNum)
				}
			];
			legendData = ['化解成功', '化解不成功'];
		} else {
			// 普通柱状图模式
			series = [
				{
					name: '数量',
					type: 'bar',
					barWidth: '40%',
					itemStyle: {
						color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
							{
								offset: 0,
								color: barColor[0]
							},
							{
								offset: 1,
								color: barColor[1]
							}
						])
					},
					data: data.map(item => item.caseNum)
				}
			];
			// legendData = ['数量'];
		}

		const option = {
			tooltip: {
				trigger: 'axis',
				axisPointer: {
					type: 'shadow'
				},
				formatter: function(params) {
					let result = `${params[0].axisValue}<br/>`;
					params.forEach(item => {
						result += `${item.seriesName}: ${item.value}<br/>`;
					});
					return result;
				}
			},
			legend: {
				data: legendData,
				bottom: 0,
				itemWidth: 10,
				itemHeight: 10
			},
			grid: {
				left: '3%',
				right: '4%',
				bottom: '10%',
				top: '3%',
				containLabel: true
			},
			xAxis: [
				{
					type: 'category',
					data: dataAxis,
					axisTick: {
						alignWithLabel: true
					},
					axisLabel: {
						color: '#666',
						interval: 0,
						rotate: dataAxis.length > 5 ? 40 : 0
					}
				}
			],
			yAxis: [
				{
					type: 'value',
					axisLine: {
						show: false
					},
					axisTick: {
						show: false
					},
					splitLine: {
						lineStyle: {
							type: 'dashed',
							color: '#eee'
						}
					},
					axisLabel: {
						color: '#666'
					}
				}
			],
			series: series
		};

		chartInstance.current.setOption(option);
	};

	return <div ref={chartRef} style={{ width: '100%', height: '100%' }} />;
};

export default MyChartBar;
